==> beadarray_2.2.0.zip: beadarray/doc/ImageProcessing.R <==
###################################################
### chunk number 1: options
###################################################
#line 36 "ImageProcessing.rnw"
options(width = 70)


###################################################
### chunk number 2: prelim
###################################################
#line 40 "ImageProcessing.rnw"
library(beadarray)


###################################################
### chunk number 3: readingTiff eval=FALSE
###################################################
## #line 52 "ImageProcessing.rnw"
## tiff <- readTIFF();
## data <- readBeadLevelTextFile();


###################################################
### chunk number 4: standardProcessing eval=FALSE
###################################################
## #line 68 "ImageProcessing.rnw"
## bg <- illuminaBackground(tiff, data[,3:4]);
## tiffSharp <- illuminaSharpen(tiff);
## fg <- illuminaForeground(tiffSharp, data[,3:4]);
## finalIntensity <- fg - bg;


###################################################
### chunk number 5: creatingObject eval=FALSE
###################################################
## #line 79 "ImageProcessing.rnw"
## BLData <- new(Class = "beadLevelData");
## BLData <- insertBeadData(BLData, array = 1, what = "Grn", data = finalIntensity)


###################################################
### chunk number 6: usingReadIllumina eval=FALSE
###################################################
## #line 88 "ImageProcessing.rnw"
## BLData <- readIllumina();
## BLData <- insertBeadData(BLData, array = 1, what = "Grn", data = finalIntensity)
## BLData <- insertBeadData(BLData, array = 1, what = "GrnLog", data = log2(finalIntensity))


###################################################
### chunk number 7: alternativeMethods eval=FALSE
###################################################
## #line 98 "ImageProcessing.rnw"
## bg <- medianBackground(tiff, data[,3:4]);


###################################################
### chunk number 8: sessionInfo
###################################################
#line 126 "ImageProcessing.rnw"
sessionInfo()

==> beadarray_2.4.2.zip: beadarray/doc/ImageProcessing.R <==
### R code from vignette source 'ImageProcessing.rnw'

###################################################
### code chunk number 1: options
###################################################
options(width = 70)


###################################################
### code chunk number 2: prelim
###################################################
library(beadarray)


###################################################
### code chunk number 3: readingTiff (eval = FALSE)
###################################################
## tiff <- readTIFF();
## data <- readBeadLevelTextFile();


###################################################
### code chunk number 4: standardProcessing (eval = FALSE)
###################################################
## bg <- illuminaBackground(tiff, data[,3:4]);
## tiffSharp <- illuminaSharpen(tiff);
## fg <- illuminaForeground(tiffSharp, data[,3:4]);
## finalIntensity <- fg - bg;


###################################################
### code chunk number 5: creatingObject (eval = FALSE)
###################################################
## BLData <- new(Class = "beadLevelData");
## BLData <- insertBeadData(BLData, array = 1, what = "Grn", data = finalIntensity)


###################################################
### code chunk number 6: usingReadIllumina (eval = FALSE)
###################################################
## BLData <- readIllumina();
## BLData <- insertBeadData(BLData, array = 1, what = "Grn", data = finalIntensity)
## BLData <- insertBeadData(BLData, array = 1, what = "GrnLog", data = log2(finalIntensity))


###################################################
### code chunk number 7: alternativeMethods (eval = FALSE)
###################################################
## bg <- medianBackground(tiff, data[,3:4]);


###################################################
### code chunk number 8: sessionInfo
###################################################
sessionInfo()
